@@ -6,5 +6,5 @@ class date():
         return name
 
     def getNameWhipptree(self):
-        name = str(random.choice(range(10, 999))) + '-' + str(random.choice(range(10, 999)))
+        name = str(random.choice(range(10, 999)))  + str(random.choice(range(10, 999)))
         return name
\ No newline at end of file
